==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/link/lang/id.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'id', {
	acccessKey: 'Access Key', // MISSING
	advanced: 'Advanced', // MISSING
	advisoryContentType: 'Advisory Content Type', // MISSING
	advisoryTitle: 'Penasehat Judul',
	anchor: {
		toolbar: 'Anchor', // MISSING
		menu: 'Edit Anchor', // MISSING
		title: 'Anchor Properties', // MISSING
		name: 'Anchor Name', // MISSING
		errorName: 'Please type the anchor name', // MISSING
		remove: 'Remove Anchor' // MISSING
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'Kelas Stylesheet',
	emailAddress: 'E-Mail Address', // MISSING
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Message Subject', // MISSING
	id: 'Id',
	info: 'Link Info', // MISSING
	langCode: 'Kode Bahasa',
	langDir: 'Arah Bahasa',
	langDirLTR: 'Kiri ke Kanan (LTR)',
	langDirRTL: 'Kanan ke Kiri (RTL)',
	menu: 'Edit Link', // MISSING
	name: 'Nama',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Please type the e-mail address', // MISSING
	noUrl: 'Please type the link URL', // MISSING
	other: '<other>', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Relationship', // MISSING
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'Gaya',
	tabIndex: 'Tab Index', // MISSING
	target: 'Sasaran',
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'Tautan',
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL',
	toolbar: 'Tautan',
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'Unggah'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/link/lang/id.js <==
﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'id', {
	acccessKey: 'Access Key', // MISSING
	advanced: 'Advanced', // MISSING
	advisoryContentType: 'Advisory Content Type', // MISSING
	advisoryTitle: 'Penasehat Judul',
	anchor: {
		toolbar: 'Anchor', // MISSING
		menu: 'Edit Anchor', // MISSING
		title: 'Anchor Properties', // MISSING
		name: 'Anchor Name', // MISSING
		errorName: 'Please type the anchor name', // MISSING
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Remove Anchor' // MISSING
	},
	anchorId: 'By Element Id', // MISSING
	anchorName: 'By Anchor Name', // MISSING
	charset: 'Linked Resource Charset', // MISSING
	cssClasses: 'Kelas Stylesheet',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Alamat E-mail',
	emailBody: 'Message Body', // MISSING
	emailSubject: 'Judul Pesan',
	id: 'Id',
	info: 'Link Info', // MISSING
	langCode: 'Kode Bahasa',
	langDir: 'Arah Bahasa',
	langDirLTR: 'Kiri ke Kanan (LTR)',
	langDirRTL: 'Kanan ke Kiri (RTL)',
	menu: 'Sunting Tautan',
	name: 'Nama',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'Silahkan ketikkan alamat e-mail',
	noUrl: 'Silahkan ketik URL tautan',
	noTel: 'Please type the phone number', // MISSING
	other: '<lainnya>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependent (Netscape)', // MISSING
	popupFeatures: 'Popup Window Features', // MISSING
	popupFullScreen: 'Full Screen (IE)', // MISSING
	popupLeft: 'Left Position', // MISSING
	popupLocationBar: 'Location Bar', // MISSING
	popupMenuBar: 'Menu Bar', // MISSING
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Scroll Bars', // MISSING
	popupStatusBar: 'Status Bar', // MISSING
	popupToolbar: 'Toolbar', // MISSING
	popupTop: 'Top Position', // MISSING
	rel: 'Hubungan',
	selectAnchor: 'Select an Anchor', // MISSING
	styles: 'Gaya',
	tabIndex: 'Tab Index', // MISSING
	target: 'Sasaran',
	targetFrame: '<frame>', // MISSING
	targetFrameName: 'Target Frame Name', // MISSING
	targetPopup: '<popup window>', // MISSING
	targetPopupName: 'Popup Window Name', // MISSING
	title: 'Tautan',
	toAnchor: 'Link to anchor in the text', // MISSING
	toEmail: 'E-mail', // MISSING
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Tautan',
	type: 'Link Type', // MISSING
	unlink: 'Unlink', // MISSING
	upload: 'Unggah'
} );
